@@ -3,6 +3,8 @@ import logging
 import time
 import re
 import urlparse
+import string
+import random
 
 from redis.exceptions import ResponseError
 import requests
@@ -16,7 +18,7 @@ class Ripper(object):
     timeout = 40
     agent = "Reddrip v1.0"
     submission_limit = 50
-    supported_exts = [ "jpg", "png", "gif" ]
+    supported_exts = [ "jpg", "jpeg", "png", "gif" ]
 
     def __init__(self, redis_conn, output_dir):
         self.redis_conn = redis_conn
@@ -24,8 +26,15 @@ class Ripper(object):
 
         self.reddit = praw.Reddit(user_agent=self.agent)
 
+    def _random_name(self, size=10, chars=string.ascii_lowercase +
+                                          string.digits):
+        return ''.join(random.choice(chars) for x in range(size))
+
     def _clean_title(self, title):
-        return re.sub(r'([^\s\w]|_)+', '', title)[:128].lower()
+        title = re.sub(r'([^\s\w]|_)+', '', title)[:128].lower()
+        if len(title) < 4:
+            title = self._random_name()
+        return title
 
     def _get_ext(self, url):
         url_info = urlparse.urlparse(url)
@@ -52,9 +61,15 @@ class Ripper(object):
             full_file = "%s/%s_%s.%s" % (subdir, filename, suffix, ext)
             suffix += 1
 
-        r = requests.get(url)
-        with open(full_file, "wb") as output:
-            output.write(r.content)
+        # TODO: implement retrying with incremental backoff.
+        try:
+            r = requests.get(url)
+            with open(full_file, "wb") as output:
+                output.write(r.content)
+            log.info("Saved %s in %s: %s" % (sub_id, subreddit, filename))
+        except requests.exceptions.RequestException:
+            log.debug("Failed to save %s" % sub_id)
+            return False
 
         # Increment saved number.
         self.redis_conn.incr("stat:%s:saved:count" % subreddit)
@@ -76,9 +91,10 @@ class Ripper(object):
             )
         self.redis_conn.incr("stat:%s:date:%s" % (subreddit, datehour))
 
-        log.info("Saved %s in %s: %s" % (sub_id, subreddit, filename))
         time.sleep(1)
 
+        return True
+
     def process(self, sub):
         log.debug("Processing %s" % sub["name"])
 
